import javax.swing.ImageIcon;
import java.util.*;

/** 
* This class creates the statuses for the pet, sets the hunger of the pet at 10, calls
*  up the images used to visually depict the pet, as well as what happens to the pet
*  when the buttons from PetPanel are clicked.
* 
* @author Carlos Rios (gth700w)
* @version 1.0 02/25/2011
*/ 

public class Pet
{

	/**
	* This class sets the states the pet can be in.
	*/
	
	public enum State
	{
		Sleeping, Eating, Dead, Laughing, Normal
	};

	/**
	*@param petState The current state of the pet
	*@param sleeping The sleeping states the pet can be in
	*@param eating The eating states the pet can be in
	*@param dead The dead states the pet can be in
	*@param laughing The laughing states the pet can be in
	*@param normal The normal states the pet can be in
	*@param full This is the set value of the pet's hunger from the start, and the max
	*@param hunger This numerical value of the pet's hunger
	*/ 
 	private State petState;
	private ImageIcon sleeping, eating, dead, laughing, normal;
	private final int full = 10; 
	private int hunger;

	/**
	* This class sets the pet's state to normal, the hunger to full (10), and calls up
	* the images used to visually depict the pet's state.
	*/	
 	public Pet ()
 	{
      petState = State.Normal;
		hunger = full;
		sleeping = new ImageIcon("sleeping.png");
		eating = new ImageIcon("eating.png");
		dead = new ImageIcon("dead.png");
		laughing = new ImageIcon("laughing.png");
		normal = new ImageIcon("normal.png");
 	}

	/**
	* This class calls up the image that visually depicts the pet's state as a image depending
	* on what state the pet is in (i.e. if pet is sleeping, a picture of the pet
	* sleeping will show.
	*
	*@return sleeping Calls up the sleeping image of the pet for the sleeping state
	*@return eating Calls up the eating image of the pet for the eating state
	*@return dead Calls up the dead image of the pet for the dead state
	*@return laughing Calls up the laughing image of the pet for the laughing state
	*@return normal Calls up the normal image of the pet for the normal state

	*/	
	public ImageIcon getCurrentIcon()
	{
		if(petState == State.Sleeping)
			return sleeping;
		else if(petState == State.Eating)
			return eating;
		else if(petState == State.Dead)
			return dead;			
		else if(petState == State.Laughing)
			return laughing;
		else
			return normal;	
	}

	/**
	* This class returns the hunger value of the pet after each button click.
	*
	* @return The hunger value of the pet.
	*/		
	public int getHunger()
	{
		return hunger;
	}

	/**
	* This class checks if the value of the pet's hunger after a poke,
	* which decreases the hunger value by one (1).
	* 
	* @return The pet's state as "dead" if it's already dead.
	*/		
	public void poke()
	{
		checkForStarvation();
		
		if(petState == State.Dead)
			return;
		
		petState = State.Laughing;
		hunger--;
	}


	/**
	* This class returns the pet's state as already dead, dead after overfeeding (past hunger value of 10,
	* or gives the pet's hunger an increase of one (1) if else.
	* 
	* @return The dead state of the pet.
	*/		
	public void feed()
	{
		if(petState == State.Dead)
			return;
		else if(hunger >= 10)
			petState = State.Dead;
		else {
			petState = State.Eating;
			hunger++;
		}
	}

	/**
	* This class checks if the pet is already dead, and returns the dead state if so.
	*  If not, the pet will be set to a state of sleep.
	* 
	* @return The dead state of the pet.
	*/		
	public void sleep()
	{
		if(petState == State.Dead)
			return;
		
		petState = State.Sleeping;
	
	}

	/**
	* This class checks if the pet is already dead, and returns the dead state if so.
	*  If not, the pet will be set to a state of normal with a decrease in hunger
	*  by one (1).
	* 
	* @return The dead state of the pet. 
	*/	
	public void sit()
	{
		if(petState == State.Dead)
			return;
	
		petState = State.Normal;
		hunger = hunger - 1;	
	}

	/**
	* This class randomly assigns poke, sit, or sleep as an action on the pet when the "watch"
	*  button is clicked. 
	* 
	* @param method This is the value of the action (1 to 3), which is assigned to
	*  an action (poke, sit or sleep).
	*/		
	public void watch()
	{
		Random rand = new Random();
		int method = rand.nextInt(3);
		if(method == 0)
			poke();
		else if(method == 1)
			sit();
		else
			sleep();
	}

	/**
	* This class checks kills the pet and sets the state of the pet as dead :(
	*/		
	public void kill()
	{
		petState = State.Dead;
	}

	/**
	* This class checks if the pet's hunger is 0, and if so, the pet is put in the 
	* state of "dead".
	*/		
	public void checkForStarvation()
	{
		if(hunger == 0)
			petState = State.Dead;
	}
}