import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/** 
* This class creates the JButtons for the user to interact with, the labels depicting
*  the status of the pet (hunger value and visual of pet). It also contains the 
*  conditionals and action listeners set to what happens when each button is clicked . 
*  It updates the status of the pet by refreshing after each click.
* 
* @author Carlos Rios (gth700w) 
* @version 1.0 02/25/2011
*/ 

public class PetPanel extends JPanel
{

	/**
	*@Button feed This is the button that will activate the feed method
	*@JButton watch This is the button that will activate the watch method
	*@JButton kill This is the button that will activate the kill method	
	*@JButton poke This is the button that will activate the poke method
	*@JLabel hungerLabel This is where the hunger value of the pet shows
	*@JLabel picLabel This is where the picture of the pet's state will show
	*@Pet pet This is the pet object
	*/
	private JButton feed;
	private JButton watch;
	private JButton kill;
	private JButton poke;
	
	private JLabel hungerLabel;
	private JLabel picLabel;
	
	private Pet pet;

	/**
	* This class makes the buttons for the GUI and the actionlistener detailing
	*  what will happen when the button is clicked. Also makes the dimensions of the JFrame
	* Makes a new pet as well as displays the hunger value and picture state of the pet.
	*/		
	public PetPanel() {
		setPreferredSize (new Dimension(450, 450));
		poke = new JButton ("Poke");
		poke.addActionListener (new ButtonListener());
										
		feed = new JButton ("Feed");
		feed.addActionListener (new ButtonListener());
		
		watch = new JButton ("Watch");
		watch.addActionListener (new ButtonListener());
	
		kill = new JButton ("Kill");
		kill.addActionListener (new ButtonListener());
		
		pet = new Pet();
		
		hungerLabel = new JLabel("Hunger: " + pet.getHunger());
		picLabel = new JLabel(pet.getCurrentIcon());
		
		add(hungerLabel);
		add(picLabel);
		add(poke);
		add(watch);
		add(feed);
		add(kill);
	}

	/**
	* This class updates the current picture of the pet and the hunger after each click.
	*/		
	public void refresh()
	{
		picLabel.setIcon(pet.getCurrentIcon());
		hungerLabel.setText(pet.getHunger()+"");
	}

	/**
	* This class makes event listeners (i.e., when a button is clicked, the action for that
	*  button is set). For example, clicking the kill button will kill the pet. It then updates
	*  with the refresh method.
	*/		
	private class ButtonListener implements ActionListener
	{
		public void actionPerformed(ActionEvent evt)
		{
		
			if (evt.getSource() == poke)
			{
				pet.poke();
			}
			else if (evt.getSource() == watch)
			{
				pet.watch();
			}
			else if (evt.getSource() == feed)
			{
				pet.feed();
			}
			else if (evt.getSource() == kill)
			{
				pet.kill();
			}

			refresh();	
		}
	}
}